@@ -1,14 +1,22 @@
 from loguru import logger
+import sys
 from ._bsl_type import _bsl_type as bsl_type
 from ._bsl_inst_info import _bsl_inst_info_class as inst
 
 logger_opt = logger.opt(ansi=True)
 
-@logger.catch(exclude=(bsl_type.DeviceConnectionFailed,bsl_type.DeviceInconsistentError,bsl_type.DeviceOperationError))
+# @logger.catch(exclude=(bsl_type.DeviceConnectionFailed,bsl_type.DeviceInconsistentError,bsl_type.DeviceOperationError))
 class _bsl_logger:
     def __init__(self, cur_inst: inst, device_id: str="N/A") -> None:
         self.__inst = cur_inst
         self.device_id = device_id
+        logger.configure(
+        handlers=[
+            {
+                "sink": sys.stderr,
+                "format": "<green>{time:HH:mm:ss}</green> | <level>{level}</level> | {function}:{line} - <level>{message}</level>"
+            }
+        ])
         logger.info(f"    {self.__inst.MODEL}  ({self.device_id}) - Logger instance initilized")
         pass
 
@@ -17,7 +25,7 @@ class _bsl_logger:
 
     def error(self, msg:str="") -> None:
         logger.error(f"ERROR - {self.__inst.MODEL}  ({self.device_id})- {msg}")
-        raise bsl_type.DeviceOperationError
+        # raise bsl_type.DeviceOperationError
 
     def warning(self, msg:str="") -> None:
         logger.warning(f"    {self.__inst.MODEL}  ({self.device_id}) - {msg}")
