@@ -28,7 +28,8 @@ class RS_7_1:
         LEN_CHANS_NO_WHITE = list([3,4,5,6,7,8,11,13,14,16,19,20,21,22,23,24,26,27,28,29,33,34,36,39,41,42,43,45,46,47,49,51,52,53,54,55,57,59,60,61])
         FWHM = list([0.0, 0.0, 13.62, 27.44, 13.62, 16.41, 30.97, 14.81, 0.0, 0.0, 22.25, 0.0, 18.07, 24.06, 0.0, 14.81, 0.0, 0.0, 35.15, 106.8, 106.8, 32.22, 25.21, 18.53, 0.0, 20.28, 79.39, 79.39, 24.06, 13.62, 0.0, 0.0, 40.32, 17.83, 0.0, 21.05, 16.15, 0.0, 33.17, 0.0, 19.7, 24.06, 21.86, 0.0, 24.06, 31.81, 16.94, 0.0, 21.27, 0.0, 20.94, 29.85, 52.46, 21.36, 21.36, 0.0, 18.53, 0.0, 15.1, 21.86, 27.68, 31.81, 0.0, 0.0])
         WAVELENGTH = list([0.0, 0.0, 590.35, 498.75, 590.35, 399.0, 521.85, 627.11, 0.0, 0.0, 769.71, 0.0, 657.0, 712.89, 0.0, 627.11, 0.0, 0.0, 845.9, 571.15, 571.15, 901.51, 746.37, 632.75, 0.0, 452.86, 610.19, 610.19, 712.89, 590.35, 5990.9, 0.0, 936.91, 426.01, 0.0, 688.43, 616.27, 2937.8, 531.37, 0.0, 445.77, 729.16, 495.49, 0.0, 729.16, 525.64, 667.09, 0.0, 407.85, 0.0, 753.59, 474.73, 959.3, 700.74, 700.74, 0.0, 632.75, 0.0, 426.8, 495.49, 802.68, 525.64, 2747.6, 0.0])
-    
+    class MACBECH_COLOR(enum.Enum):
+        CIExy = list([(0.4336, 0.3787), (0.4187, 0.3749), (0.2757, 0.2996), (0.3688, 0.4501), (0.3016, 0.2871), (0.2856, 0.3905), (0.5291, 0.4081), (0.2335, 0.2157), (0.5002, 0.3295), (0.3316, 0.2544), (0.3986, 0.5002), (0.4960, 0.4426), (0.2042, 0.1676), (0.3262, 0.5040), (0.5734, 0.3284), (0.4693, 0.4730), (0.4175, 0.2702), (0.2146, 0.3028), (0.3486, 0.3625)])
     def __init__(self, device_sn="", power_on_test:bool = True) -> None:
         self._target_device_sn = device_sn
         self.inst = inst.RS_7_1
@@ -383,7 +384,7 @@ class RS_7_1:
         return None
 
     #checked
-    def set_power_chans(self, chans:Union['list[int]', NDArray[np.int_], int], powers:Union['list[float]', NDArray[np.float_], float], unit:POWER_UNIT=POWER_UNIT.PERCENTAGE, irr_distance_mm:int=0) -> None:
+    def set_power_chans(self, chans:Union['list[int]', NDArray[np.int_], int], powers:Union['list[float]', NDArray[np.float64], float], unit:POWER_UNIT=POWER_UNIT.PERCENTAGE, irr_distance_mm:int=0) -> None:
         """
         - Set the output power of the individual LED channel[s] tothe 
         specified unit and power.
@@ -549,7 +550,7 @@ class RS_7_1:
     #checked
     def set_spectrum_raw(
         self, 
-        spectrum:Union['list[float]', NDArray[np.float_]], 
+        spectrum:Union['list[float]', NDArray[np.float64]], 
         *,
         power:float=0, 
         power_unit:POWER_UNIT=POWER_UNIT.RADIANCE, 
@@ -664,6 +665,7 @@ class RS_7_1:
         self._com_cmd(f"CCS{CIEx:.6f},{CIEy:.6f}")
         self.logger.debug(f"Set output spectrum to CIExy chromaticity {CIEx:.6f},{CIEy:.6f}.")
         return self.get_chromaticity_output()
+        
 
     #checked
     def set_spectrum_black_body(
@@ -710,6 +712,72 @@ class RS_7_1:
         self.set_spectrum_raw(spectrum, power=power, power_unit=power_unit, irr_distance_mm=irr_distance_mm)
         return self.get_color_temp()
 
+    def set_spectrum_hsv(
+        self, H:float, S:float, V:float,
+        power:float=0, power_unit:POWER_UNIT=POWER_UNIT.RADIANCE, irr_distance_mm:int=0
+        ) -> float:
+        """
+        - Set output spectrum to a specified HSV color profile.
+        
+        - Set `match_chrom = Ture` when calling set_`power_fitted_spectrum()`
+        to maintain the chromaticity matching. 
+
+        Uses
+        ----------
+        >>> set_spectrum_hsv(125,250,85,400)
+        >>> set_power_output(20, match_chrom=True)
+
+        Parameters
+        ----------
+        H : `float`
+            Hue from 0 to 360 degrees.
+
+        S : `float`
+            Saturation from 0 to 100 percent.
+
+        V : `float`
+            Value from 0 to 100.
+        
+        Returns
+        --------
+        RMS_Error : `float`
+            Root-Mean-Square error for the fitted specturm.
+        """
+
+        # Convert saturation and value to a range of 0 to 1
+        S /= 100.0
+        V /= 100.0
+        # Calculate the chroma
+        chroma = V * S
+
+        # Find the position within the hexagon
+        hue_prime = H / 60.0
+        x = chroma * (1 - abs(hue_prime % 2 - 1))
+
+        # Compute the intermediate RGB values based on the hue_prime
+        if hue_prime < 1:
+            r1, g1, b1 = chroma, x, 0
+        elif hue_prime < 2:
+            r1, g1, b1 = x, chroma, 0
+        elif hue_prime < 3:
+            r1, g1, b1 = 0, chroma, x
+        elif hue_prime < 4:
+            r1, g1, b1 = 0, x, chroma
+        elif hue_prime < 5:
+            r1, g1, b1 = x, 0, chroma
+        else:
+            r1, g1, b1 = chroma, 0, x
+
+        # Match the luminance by adding the same amount to each component
+        m = V - chroma
+        r, g, b = r1 + m, g1 + m, b1 + m
+
+        # Convert to 8-bit values
+        r, g, b = int(r * 255), int(g * 255), int(b * 255)
+
+        return self.set_spectrum_rgb(r,g,b,power,power_unit,irr_distance_mm)
+    
+
     #checked
     def set_spectrum_rgb(
         self, r:np.uint8, g:np.uint8, b:np.uint8,
@@ -913,7 +981,10 @@ class RS_7_1:
         """
         temp = self._com_query('CCT')
         if temp != "":
-            temp=float(temp)
+            try:
+                temp=float(temp)
+            except Exception:
+                temp = -1
         else:
             temp=0
         self.logger.debug(f"Current output spectrum's equivalence color temperature: {temp:.1f} Kelvins.")
@@ -929,7 +1000,10 @@ class RS_7_1:
         RMS_Error : `float`
             Root-Mean-Square error for the fitted specturm vs. provided spectrum.
         """
-        erms = float(self._com_query("RPE"))
+        try:
+            erms = float(self._com_query("RPE"))
+        except Exception:
+            erms = -1
         self.logger.debug(f"Output spectrum matching RMS Error: {erms:.3f}.")
         return erms
 
